@@ -1,4 +1,5 @@
-from langchain.schema import HumanMessage, AIMessage  # type: ignore
+from langchain.schema import AIMessage, HumanMessage  # type: ignore
+
 from .file import File
 
 
@@ -21,7 +22,7 @@ class CodeInterpreterResponse(AIMessage):
         print("AI: ", self.content)
         for file in self.files:
             file.show_image()
-    
+
     def __str__(self):
         return self.content
 
